This module manages native extensions supported by the unit testing framework. Such extensions are enabled by cfg features and must be compiled into the test to be usable.

Functions

Sets a hook which is called to populate additional native extensions. This can be used to get extensions living outside of the Move repo into the unit testing environment.